camelot.camelot.view.controls.tableview

Package camelot :: Package camelot :: Package view :: Package controls :: Module tableview |
[hide private]
[frames] | no frames]

# Module tableview

source code

Tableview

Classes | [hide private]
| QueryTable the actual displayed table
| TableView emits the row_selected signal when a row has been selected

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.controls.tableview')`
| verbose = `False`